/*

  This file is part of the Node Digest.

  Node Digest is free software: you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  Node Digest is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with Node Digest . If not, see <https://www.gnu.org/licenses/>.

*/
/*
  eslint-disable
  canonical/filename-match-exported,
  no-unused-vars
*/

import {
  recommended as canonicalTypeScript
} from 'eslint-config-canonical/typescript';
import {
  recommended as canonicalCompatibility
} from 'eslint-config-canonical/typescript-compatibility';
import {
  recommended as canonicalTypeScriptTypeChecking
} from 'eslint-config-canonical/typescript-type-checking';
import {
  flatConfigs as importPluginFlatConfigs
} from 'eslint-plugin-import';
import tseslint from 'typescript-eslint';

const {
  '@typescript-eslint/func-call-spacing': functionCallSpacing,
  '@typescript-eslint/indent': indent,
  '@typescript-eslint/object-curly-spacing': objectCurlySpacing,
  '@typescript-eslint/type-annotation-spacing': typeAnnotationSpacing,
  ...canonicalTypeScriptFixedRules
} = canonicalTypeScript[0].rules;

const {
  '@typescript-eslint/func-call-spacing': functionCallSpacing2,
  '@typescript-eslint/indent': indent2,
  ...canonicalCompatibilityFixedRules
} = canonicalCompatibility[0].rules;

const typescriptConfigs = tseslint.config(
  {
    extends: [
      importPluginFlatConfigs.typescript,
      ...tseslint.configs.strictTypeChecked,
      ...tseslint.configs.stylisticTypeChecked,
      {
        ...canonicalTypeScript[0],
        plugins: {
          functional: canonicalTypeScript[0].plugins.functional
        },
        rules: {
          ...canonicalTypeScriptFixedRules,
          '@stylistic/member-delimiter-style': [
            2,
            {
              multiline: {
                delimiter: 'semi',
                requireLast: true,
              },
              overrides: {
                interface: {
                  multiline: {
                    delimiter: 'semi',
                    requireLast: true,
                  },
                },
              },
              singleline: {
                delimiter: 'semi',
                requireLast: false,
              },
            },
          ],
        }
      },
      {
        ...canonicalTypeScriptTypeChecking[0]
      },
      {
        ...canonicalCompatibility[0],
        rules: canonicalCompatibilityFixedRules
      },
      {
        rules: {
          '@typescript-eslint/no-unused-expressions': 'off'
        }
      }
    ],
    files: [
      '**/*.{ts,tsx}'
    ],
    languageOptions: {
      parserOptions: {
        projectService: true,
        tsconfigRootDir: import.meta.dirname
      }
    }
  }
);

export default typescriptConfigs;
